==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/usermanager/lang/de/lang.php <==
<?php
/**
 * German language file
 *
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Michael Klier <chi@chimeric.de>
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 */
$lang['menu']                  = 'Benutzerverwaltung';
$lang['noauth']                = '(Authentifizierungssystem nicht verfügbar)';
$lang['nosupport']             = '(Benutzerverwaltung nicht unterstützt)';
$lang['badauth']               = 'Ungültige Methode zur Authentifizierung';
$lang['user_id']               = 'Benutzername';
$lang['user_pass']             = 'Passwort';
$lang['user_name']             = 'Voller Name';
$lang['user_mail']             = 'E-Mail';
$lang['user_groups']           = 'Gruppen';
$lang['field']                 = 'Feld';
$lang['value']                 = 'Wert';
$lang['add']                   = 'Hinzufügen';
$lang['delete']                = 'Löschen';
$lang['delete_selected']       = 'Ausgewählte löschen';
$lang['edit']                  = 'Ändern';
$lang['edit_prompt']           = 'Benutzerdaten ändern';
$lang['modify']                = 'Speichern';
$lang['search']                = 'Suchen';
$lang['search_prompt']         = 'Benutzerdaten filtern';
$lang['clear']                 = 'Filter zurücksetzen';
$lang['filter']                = 'Filter';
$lang['summary']               = 'Zeige Benutzer %1$d-%2$d von %3$d gefundenen. %4$d Benutzer insgesamt.';
$lang['nonefound']             = 'Keine Benutzer gefunden. %d Benutzer insgesamt.';
$lang['delete_ok']             = '%d Benutzer gelöscht';
$lang['delete_fail']           = '%d konnten nicht gelöscht werden.';
$lang['update_ok']             = 'Benutzerdaten erfolgreich geändert.';
$lang['update_fail']           = 'Änderung der Benutzerdaten fehlgeschlagen.';
$lang['update_exists']         = 'Nutzername konnte nicht geändert werden, weil der angegebene Nutzer (%s) bereits existiert (alle anderen Änderungen wurden durchgeführt).';
$lang['start']                 = 'Anfang';
$lang['prev']                  = 'Vorherige';
$lang['next']                  = 'Nächste';
$lang['last']                  = 'Ende';
$lang['edit_usermissing']      = 'Der ausgewählte Nutzer wurde nicht gefunden. Möglicherweise wurde er gelöscht oder der Nutzer wurde anderswo geändert.';
$lang['user_notify']           = 'Nutzer benachrichtigen';
$lang['note_notify']           = 'Benachrichtigungsmails werden nur versandt wenn ein neues Passwort vergeben wurde.';
$lang['note_group']            = 'Neue Nutzer werden der Standard-Gruppe (%s) hinzugefügt, wenn keine Gruppe angegeben wurde.';
$lang['note_pass']             = 'Das Password wird automatisch generiert wenn das entsprechende Feld leergelassen wird und die Benachrichtigung des Nutzers aktiviert ist.';
$lang['add_ok']                = 'Nutzer erfolgreich angelegt';
$lang['add_fail']              = 'Nutzer konnte nicht angelegt werden';
$lang['notify_ok']             = 'Benachrichtigungsmail wurde versandt';
$lang['notify_fail']           = 'Benachrichtigungsmail konnte nicht versandt werden';

==> dokuwiki_0.0.20110525a.orig.tar.gz: dokuwiki-2011-05-25a/lib/plugins/usermanager/lang/de/lang.php <==
<?php
/**
 * German language file
 *
 * @author Matthias Grimm <matthiasgrimm@users.sourceforge.net>
 * @author Andreas Gohr <andi@splitbrain.org>
 * @author Michael Klier <chi@chimeric.de>
 * @author Leo Moll <leo@yeasoft.com>
 * @author Florian Anderiasch <fa@art-core.org>
 * @author Robin Kluth <commi1993@gmail.com>
 * @author Arne Pelka <mail@arnepelka.de>
 * @author Dirk Einecke <dirk@dirkeinecke.de>
 * @author Blitzi94@gmx.de
 * @author Robert Bogenschneider <robog@GMX.de>
 * @author Robert Bogenschneider <robog@gmx.de>
 * @author Niels Lange <niels@boldencursief.nl>
 * @author Christian Wichmann <nospam@zone0.de>
 */
$lang['menu']                  = 'Benutzerverwaltung';
$lang['noauth']                = '(Authentifizierungssystem nicht verfügbar)';
$lang['nosupport']             = '(Benutzerverwaltung nicht unterstützt)';
$lang['badauth']               = 'Ungültige Methode zur Authentifizierung';
$lang['user_id']               = 'Benutzername';
$lang['user_pass']             = 'Passwort';
$lang['user_name']             = 'Voller Name';
$lang['user_mail']             = 'E-Mail';
$lang['user_groups']           = 'Gruppen';
$lang['field']                 = 'Feld';
$lang['value']                 = 'Wert';
$lang['add']                   = 'Hinzufügen';
$lang['delete']                = 'Löschen';
$lang['delete_selected']       = 'Ausgewählte löschen';
$lang['edit']                  = 'Ändern';
$lang['edit_prompt']           = 'Benutzerdaten ändern';
$lang['modify']                = 'Speichern';
$lang['search']                = 'Suchen';
$lang['search_prompt']         = 'Benutzerdaten filtern';
$lang['clear']                 = 'Filter zurücksetzen';
$lang['filter']                = 'Filter';
$lang['summary']               = 'Zeige Benutzer %1$d-%2$d von %3$d gefundenen. %4$d Benutzer insgesamt.';
$lang['nonefound']             = 'Keine Benutzer gefunden. %d Benutzer insgesamt.';
$lang['delete_ok']             = '%d Benutzer gelöscht';
$lang['delete_fail']           = '%d konnten nicht gelöscht werden.';
$lang['update_ok']             = 'Benutzerdaten erfolgreich geändert.';
$lang['update_fail']           = 'Änderung der Benutzerdaten fehlgeschlagen.';
$lang['update_exists']         = 'Nutzername konnte nicht geändert werden, weil der angegebene Nutzer (%s) bereits existiert (alle anderen Änderungen wurden durchgeführt).';
$lang['start']                 = 'Anfang';
$lang['prev']                  = 'Vorherige';
$lang['next']                  = 'Nächste';
$lang['last']                  = 'Ende';
$lang['edit_usermissing']      = 'Der ausgewählte Nutzer wurde nicht gefunden. Möglicherweise wurde er gelöscht oder der Nutzer wurde anderswo geändert.';
$lang['user_notify']           = 'Nutzer benachrichtigen';
$lang['note_notify']           = 'Benachrichtigungs-E-Mails werden nur versandt, wenn ein neues Passwort vergeben wurde.';
$lang['note_group']            = 'Neue Nutzer werden der Standard-Gruppe (%s) hinzugefügt, wenn keine Gruppe angegeben wurde.';
$lang['note_pass']             = 'Das Passwort wird automatisch generiert, wenn das entsprechende Feld leergelassen wird und die Benachrichtigung des Nutzers aktiviert ist.';
$lang['add_ok']                = 'Nutzer erfolgreich angelegt';
$lang['add_fail']              = 'Nutzer konnte nicht angelegt werden';
$lang['notify_ok']             = 'Benachrichtigungsmail wurde versandt';
$lang['notify_fail']           = 'Benachrichtigungsmail konnte nicht versandt werden';
